h-entry parsing tests

# h-entry parsing tests ‐ change logs

The files in this directory where designed to test the expanding of relative URLs to absolute URLs in the HTML content of e-* propreties.

## Change log:

- Updated JSON in order to reflect the parsing rules for src and alt attributes on img elements ‐ 24 June 2019 by Jan Sauer
- Moved from experiemental implied value nested test ‐ 8 June 2015 by Glenn Jones
- Created implied value nested test ‐ 1 June 2015 by Kyle Mahan
- Added missing space into html proprety of urlcontent test JSON ‐ 31 May 2015 by Glenn Jones
- Update text output to be textContent non-trimmed for summarycontent and urlcontent tests ‐ 29 May 2015 by Glenn Jones
- Added missing summmary property to summarycontent test ‐ 23 May 2015 by Glenn Jones
- Remove duplicate structures from items[] in summarycontent test ‐ 23 May 2015 by Glenn Jones
- Broke old HTML format into small files to aid simpler testing ‐ 21 May 2015 by Glenn Jones
- Updated encoding issue on e-* ‐ 19 September 2013 by Glenn Jones
- Created ‐ 30 June 2013 by Glenn Jones

## Contributors:

- Kyle Mahan
- Glenn Jones
- Jan Sauer